/* Create the primary call detail reporting table.  This holds all call 
 * call records being logged.  This table is originally filled from the
 * cdr collection server, and then updated by a batch process which
 * identifies and fills in city names, etc...
 */

create table calls (
	callid	varchar(32),		/* globally unique call id */
	calltype char,			/* record type */
	localization char(2),		/* localization */
	node varchar(16),		/* node id */
	port varchar(16),		/* circuit on node */
	policy varchar(16),		/* circuit group or policy */
	dialed varchar(16),		/* number dialed, dnis, etc */
	origin varchar(16),		/* caller origin, ani, etc */
	target varchar(16),		/* final destination */
	account varchar(32),		/* account code */
	date date,			/* call made */
	time time,
	duration numeric(10, 0),	/* call duration in seconds */
	location varchar(50),		/* city/state */
	cost numeric(9,2),			/* computed cost */
	sessionid varchar(32),		/* session id */
	infodigits char(2),
	final bool		/* finalized flag */
);

/* Assure database always has only one instance of unique call
 * identifier.
 */

create unique index calls_hash on calls using btree(callid);

/* Create an index for date ordered retreival */

create index calls_idx on calls(date, time);

/* Work out permissions */

revoke select on calls from public;

/* Index of regional encoding to table sets */

create table localization (
	locale char(2),
	tablename char(16),
	intprefix varchar(7),
	size numeric(2, 0),
	area numeric(1, 0),
	exchange numeric(1, 0)
);

/* Reference for processing of city names in unfilled records. */

create index local_hash on localization using hash(locale);

/* Define localizations as needed. */

insert into localization values('na', 'city_na', '011', 10, 3, 6);
insert into localization values('us', 'city_na', '011', 10, 3, 6);

/* Insert module into master table. */

insert into modules values('cdr', 'V');
